﻿using UnityEngine;
using UnityEngine.UI;
using System.Collections;

public class GameManager : MonoBehaviour {

    GameObject player;
    public CameraScript camera;

    //Game Variables
    public int roomsCleared;
    public int roomsToWin;
    bool isLoading;

    //Room Generation Variables
    public GameObject[] enemies;    //All of the enemies in the game that we want to spawn randomly in each room. To increase the odds of a certain enemy appearing, just add the prefab over and over (LOL screw performance)
    public GameObject[] elements;   //Any gameobjects that can be spawned in the middle of each room. These can be chests with pickups, traps, or just setpieces. 
    public GameObject baseRoom; //The base prefab with walls, floors, doors, etc.
    public Transform playerSpawnPosition;
    public Transform enemySpawnPosition1;
    public Transform enemySpawnPosition2;
    public Transform elementSpawnPosition;

    public Text roomsClearedText;
    public GameObject remainingEnemiesText;

    // Use this for initialization
    void Start()
    {
        player = GameObject.FindGameObjectWithTag("Player");
        player.transform.position = playerSpawnPosition.position;
        GenerateRoom();
        camera = GameObject.FindGameObjectWithTag("MainCamera").GetComponent<CameraScript>();
        camera.ToggleScreenFade();
    }

    void Update()
    {
        if (Input.GetKeyDown(KeyCode.Escape))
        {
            Application.LoadLevel(0);
        }
    }

    public void ClearRoom() //Called when the player touches the door. Ends the current room and starts spawning the next room. 
    {
        roomsCleared++;

        roomsClearedText.text = "Rooms Cleared: " + (roomsCleared - 1).ToString();

        if (roomsCleared >= roomsToWin)
        {
            //End the game
        }
        else
        {
            if (isLoading == false)
            {
                StartCoroutine(ChangeRoom());
            }
        }
    }

    IEnumerator ChangeRoom()
    {
        isLoading = true;
        //Fade the camera to black, call the generate room function, wait a certain amount of time to account for lag, then fade back in and give the player control.

        //Disable player control
        player.GetComponent<CharacterScript>().canMove = false;

        //Call fade camera to black function and wait X time, where X is the amount of time the camera takes to fade to black.
        camera.ToggleScreenFade();
        yield return new WaitForSeconds(2);

        //Delete the current room objects
        GameObject[] oldEnemies = GameObject.FindGameObjectsWithTag("Monster");
        foreach (GameObject g in oldEnemies)
        {
            Destroy(g);
        }

        GameObject[] healthPickups = GameObject.FindGameObjectsWithTag("HealthPickup");
        foreach (GameObject h in healthPickups)
        {
            Destroy(h);
        }

        GameObject oldElement = GameObject.FindGameObjectWithTag("Element");
        Destroy(oldElement);

        //Generate a new room
        GenerateRoom();

        //Move the player back to where they are supposed to be.
        player.transform.position = playerSpawnPosition.position;

        //Fade the camera back in.
        camera.ToggleScreenFade();
        yield return new WaitForSeconds(2);
        camera.ToggleScreenFade();

        //Enable player control
        player.GetComponent<CharacterScript>().canMove = true;

        isLoading = false;
    }

    void GenerateRoom()
    {
        for (int i = 0; i < roomsCleared; i++)
        {
            GameObject.Instantiate(enemies[Random.Range(0, enemies.Length)], enemySpawnPosition1.position + new Vector3(Random.Range(-2.0f, 2.0f), 0, Random.Range(-2.0f, 2.0f)), Quaternion.identity);
            GameObject.Instantiate(enemies[Random.Range(0, enemies.Length)], enemySpawnPosition2.position + new Vector3(Random.Range(-2.0f, 2.0f), 0, Random.Range(-2.0f, 2.0f)), Quaternion.identity);
        }

        GameObject.Instantiate(elements[Random.Range(0, elements.Length)], elementSpawnPosition.position, Quaternion.identity);
    }

    public void RemainingEnemies()
    {
        StartCoroutine(RemainingEnemyWarning());
    }

    IEnumerator RemainingEnemyWarning()
    {
        remainingEnemiesText.SetActive(true);
        yield return new WaitForSeconds(3);
        remainingEnemiesText.SetActive(false);
    }
}
