﻿using UnityEngine;
using UnityEngine.UI;
using UnityEngine.EventSystems;
using System.Collections;

public class StartMenuScript : MonoBehaviour {

    public GameObject titleScreen;
    public GameObject nameEntryScreen;
    public EventSystem eventSystem;
    public string playerName;
    public InputField inputField;
    public Text leaderboardText;
    AudioSource source;
    public AudioClip menuSelect;
    public AudioClip startSound;
    float exitTimer;

	// Use this for initialization
	void Start ()
    {
        source = GetComponent<AudioSource>();
        DontDestroyOnLoad(gameObject);
        titleScreen.SetActive(true);
        nameEntryScreen.SetActive(false);
        int highScore = PlayerPrefs.GetInt("HighScore");
        if (highScore != 0)
        {
            leaderboardText.text = "Best Run: " + PlayerPrefs.GetString("HighScoreName") + ": " + highScore.ToString();
        }
        else
        {
            leaderboardText.text = "";
        }

        source.PlayOneShot(startSound);
	}
	
	// Update is called once per frame
	void Update ()
    {
        exitTimer += Time.deltaTime;
        if (Input.GetKeyDown(KeyCode.Escape) & exitTimer > 3 && Application.loadedLevel == 0)
        {
            Application.Quit();
        }
        if (titleScreen != null)
        {
            if (Input.anyKeyDown && titleScreen.activeSelf == true)
            {
                titleScreen.SetActive(false);
                nameEntryScreen.SetActive(true);
                //TODO: Set the text box to active.
                EventSystem.current.SetSelectedGameObject(inputField.gameObject, null);
                inputField.OnPointerClick(new PointerEventData(EventSystem.current));
                source.PlayOneShot(menuSelect);
            }
            if (Input.GetKeyDown(KeyCode.Return) && nameEntryScreen.activeSelf == true)
            {
                if (inputField.text.Length > 0)
                {
                    playerName = inputField.text;
                    source.PlayOneShot(menuSelect);
                    Application.LoadLevel("game");
                }
            }
        }

        if (Input.GetKeyDown(KeyCode.F12))
        {
            PlayerPrefs.DeleteAll();
            leaderboardText.text = "Game Records Cleared!";
        }

    }
}
